StandardButton

Struct StandardButton 

pub struct StandardButton(/* private fields */);
These enums describe flags for standard buttons. Each button has a defined ButtonRole.

C++ enum: QMessageBox::StandardButton.

C++ documentation:

These enums describe flags for standard buttons. Each button has a defined ButtonRole.

The following values are obsolete:

This enum was introduced or modified in Qt 4.2.

The StandardButtons type is a typedef for QFlags<StandardButton>. It stores an OR combination of StandardButton values.

See also ButtonRole and standardButtons.

Implementations

Source

impl StandardButton

pub fn to_int(&self) -> c_int

Source

impl StandardButton

pub const NoButton: StandardButton

An invalid button. (C++ enum variant: NoButton = 0)

pub const Ok: StandardButton

An “OK” button defined with the AcceptRole. (C++ enum variant: Ok = 1024)

pub const Save: StandardButton

A “Save” button defined with the AcceptRole. (C++ enum variant: Save = 2048)

pub const SaveAll: StandardButton

A “Save All” button defined with the AcceptRole. (C++ enum variant: SaveAll = 4096)

pub const Open: StandardButton

An “Open” button defined with the AcceptRole. (C++ enum variant: Open = 8192)

pub const Yes: StandardButton

A “Yes” button defined with the YesRole. (C++ enum variant: Yes = 16384)

pub const YesToAll: StandardButton

A “Yes to All” button defined with the YesRole. (C++ enum variant: YesToAll = 32768)

pub const No: StandardButton

A “No” button defined with the NoRole. (C++ enum variant: No = 65536)

pub const NoToAll: StandardButton

A “No to All” button defined with the NoRole. (C++ enum variant: NoToAll = 131072)

pub const Abort: StandardButton

An “Abort” button defined with the RejectRole. (C++ enum variant: Abort = 262144)

pub const Retry: StandardButton

A “Retry” button defined with the AcceptRole. (C++ enum variant: Retry = 524288)

pub const Ignore: StandardButton

An “Ignore” button defined with the AcceptRole. (C++ enum variant: Ignore = 1048576)

pub const Close: StandardButton

A “Close” button defined with the RejectRole. (C++ enum variant: Close = 2097152)

pub const Cancel: StandardButton

A “Cancel” button defined with the RejectRole. (C++ enum variant: Cancel = 4194304)

pub const Discard: StandardButton

A “Discard” or “Don’t Save” button, depending on the platform, defined with the DestructiveRole. (C++ enum variant: Discard = 8388608)

pub const Help: StandardButton

A “Help” button defined with the HelpRole. (C++ enum variant: Help = 16777216)

pub const Apply: StandardButton

An “Apply” button defined with the ApplyRole. (C++ enum variant: Apply = 33554432)

pub const Reset: StandardButton

A “Reset” button defined with the ResetRole. (C++ enum variant: Reset = 67108864)

pub const RestoreDefaults: StandardButton

A “Restore Defaults” button defined with the ResetRole. (C++ enum variant: RestoreDefaults = 134217728)

pub const FirstButton: StandardButton

C++ enum variant: FirstButton = 1024

pub const LastButton: StandardButton

C++ enum variant: LastButton = 134217728

pub const YesAll: StandardButton

Use YesToAll instead. (C++ enum variant: YesAll = 32768)

pub const NoAll: StandardButton

Use NoToAll instead. (C++ enum variant: NoAll = 131072)

pub const Default: StandardButton

Use the defaultButton argument of information(), warning(), etc. instead, or call setDefaultButton(). (C++ enum variant: Default = 256)

pub const Escape: StandardButton

Call setEscapeButton() instead. (C++ enum variant: Escape = 512)

pub const FlagMask: StandardButton

  (C++ enum variant: FlagMask = 768)

pub const ButtonMask: StandardButton

  (C++ enum variant: ButtonMask = -769)