pub struct StandardButton(/* private fields */);Expand description
These enums describe flags for standard buttons. Each button has a defined ButtonRole.
C++ enum: QMessageBox::StandardButton.
These enums describe flags for standard buttons. Each button has a defined ButtonRole.
The following values are obsolete:
This enum was introduced or modified in Qt 4.2.
The StandardButtons type is a typedef for QFlags<StandardButton>. It stores an OR combination of StandardButton values.
See also ButtonRole and standardButtons.
Implementations
Sourceimpl StandardButton
impl StandardButton
Sourcepub const NoButton: StandardButton
pub const NoButton: StandardButton
An invalid button. (C++ enum variant: NoButton = 0)
Sourcepub const Ok: StandardButton
pub const Ok: StandardButton
An “OK” button defined with the AcceptRole. (C++ enum variant: Ok = 1024)
Sourcepub const Save: StandardButton
pub const Save: StandardButton
A “Save” button defined with the AcceptRole. (C++ enum variant: Save = 2048)
Sourcepub const SaveAll: StandardButton
pub const SaveAll: StandardButton
A “Save All” button defined with the AcceptRole. (C++ enum variant: SaveAll = 4096)
Sourcepub const Open: StandardButton
pub const Open: StandardButton
An “Open” button defined with the AcceptRole. (C++ enum variant: Open = 8192)
Sourcepub const Yes: StandardButton
pub const Yes: StandardButton
A “Yes” button defined with the YesRole. (C++ enum variant: Yes = 16384)
Sourcepub const YesToAll: StandardButton
pub const YesToAll: StandardButton
A “Yes to All” button defined with the YesRole. (C++ enum variant: YesToAll = 32768)
Sourcepub const No: StandardButton
pub const No: StandardButton
A “No” button defined with the NoRole. (C++ enum variant: No = 65536)
Sourcepub const NoToAll: StandardButton
pub const NoToAll: StandardButton
A “No to All” button defined with the NoRole. (C++ enum variant: NoToAll = 131072)
Sourcepub const Abort: StandardButton
pub const Abort: StandardButton
An “Abort” button defined with the RejectRole. (C++ enum variant: Abort = 262144)
Sourcepub const Retry: StandardButton
pub const Retry: StandardButton
A “Retry” button defined with the AcceptRole. (C++ enum variant: Retry = 524288)
Sourcepub const Ignore: StandardButton
pub const Ignore: StandardButton
An “Ignore” button defined with the AcceptRole. (C++ enum variant: Ignore = 1048576)
Sourcepub const Close: StandardButton
pub const Close: StandardButton
A “Close” button defined with the RejectRole. (C++ enum variant: Close = 2097152)
Sourcepub const Cancel: StandardButton
pub const Cancel: StandardButton
A “Cancel” button defined with the RejectRole. (C++ enum variant: Cancel = 4194304)
Sourcepub const Discard: StandardButton
pub const Discard: StandardButton
A “Discard” or “Don’t Save” button, depending on the platform, defined with the DestructiveRole. (C++ enum variant: Discard = 8388608)
Sourcepub const Help: StandardButton
pub const Help: StandardButton
A “Help” button defined with the HelpRole. (C++ enum variant: Help = 16777216)
Sourcepub const Apply: StandardButton
pub const Apply: StandardButton
An “Apply” button defined with the ApplyRole. (C++ enum variant: Apply = 33554432)
Sourcepub const Reset: StandardButton
pub const Reset: StandardButton
A “Reset” button defined with the ResetRole. (C++ enum variant: Reset = 67108864)
Sourcepub const RestoreDefaults: StandardButton
pub const RestoreDefaults: StandardButton
A “Restore Defaults” button defined with the ResetRole. (C++ enum variant: RestoreDefaults = 134217728)
Sourcepub const FirstButton: StandardButton
pub const FirstButton: StandardButton
C++ enum variant: FirstButton = 1024
Sourcepub const LastButton: StandardButton
pub const LastButton: StandardButton
C++ enum variant: LastButton = 134217728
Sourcepub const YesAll: StandardButton
pub const YesAll: StandardButton
Use YesToAll instead. (C++ enum variant: YesAll = 32768)
Sourcepub const NoAll: StandardButton
pub const NoAll: StandardButton
Use NoToAll instead. (C++ enum variant: NoAll = 131072)
Sourcepub const Default: StandardButton
pub const Default: StandardButton
Use the defaultButton argument of information(), warning(), etc. instead, or call setDefaultButton(). (C++ enum variant: Default = 256)
Sourcepub const Escape: StandardButton
pub const Escape: StandardButton
Call setEscapeButton() instead. (C++ enum variant: Escape = 512)
Sourcepub const FlagMask: StandardButton
pub const FlagMask: StandardButton
(C++ enum variant: FlagMask = 768)
Sourcepub const ButtonMask: StandardButton
pub const ButtonMask: StandardButton
(C++ enum variant: ButtonMask = -769)